Core Flyte language specification
=================================

Protocol buffers provide details about core data
structures like :ref:`workflows <divedeep-workflows>`, :ref:`tasks <divedeep-tasks>`, :ref:`nodes <divedeep-nodes>`, and Literals. They are the specifications
of the various entities in Flyte and the type system.

`Core raw protos <https://github.com/flyteorg/flyteidl/blob/master/protos/flyteidl/core>`__

.. toctree::
  :maxdepth: 1
  :caption: core
  :name: coretoc

  core
